@@ -32,7 +32,7 @@ class EpicDetectorRecipe(Recipe):
         self.config['branch'] = 'main'
         self.config['branch_epic'] = self.config['branch']
         self.config['branch_ip6'] = 'master'    # https://github.com/eic/ip6/issues/1
-        self.required_deps = ['clhep', 'eigen3', 'root', 'hepmc3', 'podio', 'edm4hep', 'geant4', 'acts',  'dd4hep']
+        self.required_deps = ['clhep', 'eigen3', 'root', 'hepmc3', 'podio', 'edm4hep', 'eicd', 'geant4', 'acts',  'dd4hep']
         self.config['repo_address_epic'] = 'https://github.com/eic/epic'
         self.config['repo_address_ip6'] = 'https://github.com/eic/ip6'
 
@@ -60,7 +60,7 @@ class EpicDetectorRecipe(Recipe):
         self.config['install_path'] = self.config['install_path_epic']
 
         # Link ip6 repo to epic, as IP6 should be linked to installed epic
-        self.config['ip6_link_source'] = "{install_path_ip6}/share/ip6".format(**self.config)
+        self.config['ip6_link_source'] = "{install_path_ip6}/share/ip6/ip6".format(**self.config)
         self.config['ip6_link_target'] = "{install_path_epic}/share/epic/ip6".format(**self.config)
 
         # cmake command:
